@@ -23,19 +23,13 @@
 
 
 /*
- * SNOOPY DATA SOURCE: cmdline
- *
- * Description:
- *     Returns command line of current process.
- *
- * Params:
- *     result: pointer to string, to write result into
- *
- * Return:
- *     number of characters in the returned string
+ * Includes order: from local to global
  */
+#include "cmdline.h"
+
 #include "snoopy.h"
 #include "inputdatastorage.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -47,7 +41,20 @@
 
 
 
-int snoopy_datasource_cmdline (char *result, char *arg)
+/*
+ * SNOOPY DATA SOURCE: cmdline
+ *
+ * Description:
+ *     Returns command line of current process.
+ *
+ * Params:
+ *     result: pointer to string, to write result into
+ *     arg:    (ignored)
+ *
+ * Return:
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
+ */
+int snoopy_datasource_cmdline (char * const result, char const * const arg)
 {
     char   *cmdLine = NULL;
     int     cmdLineArgCount;
@@ -55,15 +62,19 @@ int snoopy_datasource_cmdline (char *result, char *arg)
     int     cmdLineSizeRet;   // Size that will be returned
     int     i;
     int     n;
+    snoopy_inputdatastorage_t   *snoopy_inputdatastorage;
+
+    /* Get argument data of execv/e() call */
+    snoopy_inputdatastorage = snoopy_inputdatastorage_get();
 
     /* Count number of arguments */
-    for (cmdLineArgCount=0 ; *(snoopy_inputdatastorage_argv+cmdLineArgCount) != '\0' ; cmdLineArgCount++);
+    for (cmdLineArgCount=0 ; *(snoopy_inputdatastorage->argv+cmdLineArgCount) != '\0' ; cmdLineArgCount++);
 
     /* Calculate memory requirement for cmdLine */
     cmdLineSizeSum = 0;
     for (i=0 ; i<cmdLineArgCount ; i++) {
         /* Argument length + space */
-        cmdLineSizeSum += strlen(snoopy_inputdatastorage_argv[i]) + 1;
+        cmdLineSizeSum += strlen(snoopy_inputdatastorage->argv[i]) + 1;
     }
     /* Last space will be converted to \0 */
     cmdLineSizeRet = min(SNOOPY_SYSCONF_ARG_MAX, cmdLineSizeSum);
@@ -77,7 +88,7 @@ int snoopy_datasource_cmdline (char *result, char *arg)
         if (n >= cmdLineSizeRet) {
             break;
         }
-        n += snprintf(cmdLine+n, cmdLineSizeRet-n, "%s", snoopy_inputdatastorage_argv[i]);
+        n += snprintf(cmdLine+n, cmdLineSizeRet-n, "%s", snoopy_inputdatastorage->argv[i]);
 
         if (n >= cmdLineSizeRet) {
             break;
