@@ -22,6 +22,19 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "cwd.h"
+
+#include "snoopy.h"
+
+#include <stdio.h>
+#include <unistd.h>
+#include <limits.h>
+
+
+
 /*
  * SNOOPY DATA SOURCE: cwd
  *
@@ -30,23 +43,17 @@
  *
  * Params:
  *     result: pointer to string, to write result into
+ *     arg:    (ignored)
  *
  * Return:
- *     number of characters in the returned string
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-#include "snoopy.h"
-#include <stdio.h>
-#include <unistd.h>
-#include <limits.h>
-
-
-
-int snoopy_datasource_cwd (char *result, char *arg)
+int snoopy_datasource_cwd (char * const result, char const * const arg)
 {
     char cwdBuf[PATH_MAX+1];
 
     if (getcwd(cwdBuf, PATH_MAX+1)) {
         return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", cwdBuf);
     }
-    return -1;
+    return SNOOPY_DATASOURCE_FAILURE;
 }
