@@ -22,6 +22,18 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "filename.h"
+
+#include "snoopy.h"
+
+#include "inputdatastorage.h"
+#include <stdio.h>
+
+
+
 /*
  * SNOOPY DATA SOURCE: filename
  *
@@ -30,17 +42,17 @@
  *
  * Params:
  *     result: pointer to string, to write result into
+ *     arg:    (ignored)
  *
  * Return:
- *     number of characters in the returned string
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-#include "snoopy.h"
-#include "inputdatastorage.h"
-#include <stdio.h>
-
-
-
-int snoopy_datasource_filename (char *result, char *arg)
+int snoopy_datasource_filename (char * const result, char const * const arg)
 {
-    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", snoopy_inputdatastorage_filename);
+    snoopy_inputdatastorage_t   *snoopy_inputdatastorage;
+
+    /* Get argument data of execv/e() call */
+    snoopy_inputdatastorage = snoopy_inputdatastorage_get();
+
+    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", snoopy_inputdatastorage->filename);
 }
