@@ -22,6 +22,22 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "sid.h"
+
+#include "snoopy.h"
+
+#ifndef   _XOPEN_SOURCE   /* Needed to get getpgid and getsid on older glibc */
+#define   _XOPEN_SOURCE   500
+#endif
+#include <stdio.h>
+#include <sys/types.h>
+#include <unistd.h>
+
+
+
 /*
  * SNOOPY DATA SOURCE: sid
  *
@@ -30,20 +46,12 @@
  *
  * Params:
  *     result: pointer to string, to write result into
+ *     arg:    (ignored)
  *
  * Return:
- *     number of characters in the returned string
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-#include "snoopy.h"
-#include <stdio.h>
-/* Needed to get getpgid and getsid on older glibc */
-#define   _XOPEN_SOURCE   500
-#include <unistd.h>
-#include <sys/types.h>
-
-
-
-int snoopy_datasource_sid (char *result, char *arg)
+int snoopy_datasource_sid (char * const result, char const * const arg)
 {
     return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%u", getsid(0));
 }
