@@ -22,6 +22,19 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "src/datasource/tty.h"
+
+#include "snoopy.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <unistd.h>
+
+
+
 /*
  * SNOOPY DATA SOURCE: tty
  *
@@ -30,24 +43,30 @@
  *
  * Params:
  *     result: pointer to string, to write result into
+ *     arg:    (ignored)
  *
  * Return:
- *     number of characters in the returned string
+ *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-#include "snoopy.h"
-#include <stdio.h>
-#include <unistd.h>
-
-
-
-int snoopy_datasource_tty (char *result, char *arg)
+int snoopy_datasource_tty (char * const result, char const * const arg)
 {
-    char *ttyName = NULL;
+    char    ttyPath[SNOOPY_DATASOURCE_TTY_sizeMaxWithNull];
+    size_t  ttyPathLen = SNOOPY_DATASOURCE_TTY_sizeMaxWithoutNull;
+    int     retVal;
 
-    ttyName = ttyname(0);
-    if (NULL == ttyName) {
-        return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "(none)");
+    retVal = ttyname_r(0, ttyPath, ttyPathLen);
+    if (0 != retVal) {
+        if (EBADF == retVal) {
+            return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "ERROR(ttyname_r->EBADF)");
+        }
+        if (ERANGE == retVal) {
+            return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "ERROR(ttyname_r->ERANGE)");
+        }
+        if (ENOTTY == retVal) {
+            return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "(none)");
+        }
+        return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "ERROR(ttyname_r->EUNKNOWN)");
     }
 
-    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", ttyName);
+    return snprintf(result, SNOOPY_DATASOURCE_MESSAGE_MAX_SIZE, "%s", ttyPath);
 }
