@@ -23,22 +23,11 @@
 
 
 /*
- * Include all required C resources
+ * Includes order: from local to global
  */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <syslog.h>
-
-
-
-/*
- * Include all snoopy-related resources
- */
-#include "snoopy.h"
 #include "error.h"
+
+#include "snoopy.h"
 #include "configuration.h"
 #include "log.h"
 
@@ -59,8 +48,15 @@
  */
 void snoopy_error_handler (char *errorMsg)
 {
+    snoopy_configuration_t *CFG;
+
+
+    /* Get config pointer */
+    CFG = snoopy_configuration_get();
+
+
     /* Only send error to syslog if configured like that */
-    if (SNOOPY_TRUE == snoopy_configuration.error_logging_enabled) {
+    if (SNOOPY_TRUE == CFG->error_logging_enabled) {
         snoopy_log_dispatch(errorMsg, SNOOPY_LOG_ERROR);
     }
 }
