@@ -22,6 +22,19 @@
 
 
 
+/*
+ * Includes order: from local to global
+ */
+#include "only_root.h"
+
+#include "snoopy.h"
+
+#include <stdio.h>
+#include <sys/types.h>
+#include <unistd.h>
+
+
+
 /*
  * SNOOPY FILTER: only_root
  *
@@ -35,14 +48,7 @@
  * Return:
  *     SNOOPY_FILTER_PASS or SNOOPY_FILTER_DROP
  */
-#include "snoopy.h"
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
-
-
-
-int snoopy_filter_only_root (char *msg, char *arg)
+int snoopy_filter_only_root (char *msg, char const * const arg)
 {
     if (0 == getuid()) {
         return SNOOPY_FILTER_PASS;
