@@ -19,28 +19,56 @@
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#include "snoopy.h"
+
+
+
+/*
+ * START: Prevent cyclic inclusions
+ */
+#ifndef __SNOOPY_INPUTDATASTORAGE_H
+#define __SNOOPY_INPUTDATASTORAGE_H
 
 
 
 /*
  * Store execution data for inputs to consume
  */
-extern const char *snoopy_inputdatastorage_filename;
-extern char **snoopy_inputdatastorage_argv;
-extern char **snoopy_inputdatastorage_envp;
+typedef struct {
+    int          initialized;
+    const char  *filename;
+    char       **argv;
+    char       **envp;
+} snoopy_inputdatastorage_t;
 
 
 
 /*
- * Functions to use to do the actual storing
+ * Init functions
  */
-void snoopy_inputdatastorage_store_filename (
-    const char *filename
-);
-void snoopy_inputdatastorage_store_argv (
-    char * argv[]
-);
-void snoopy_inputdatastorage_store_envp (
-    char * envp[]
-);
+void snoopy_inputdatastorage_ctor             ();
+void snoopy_inputdatastorage_dtor             ();
+void snoopy_inputdatastorage_setUninitialized (snoopy_inputdatastorage_t *IDS);
+void snoopy_inputdatastorage_setDefaults      (snoopy_inputdatastorage_t *IDS);
+
+
+
+/*
+ * Functions that do the actual data storing
+ */
+void snoopy_inputdatastorage_store_filename (const char *filename);
+void snoopy_inputdatastorage_store_argv     (      char *argv[]  );
+void snoopy_inputdatastorage_store_envp     (      char *envp[]  );
+
+
+
+/*
+ * Retrieval functions
+ */
+snoopy_inputdatastorage_t*   snoopy_inputdatastorage_get ();
+
+
+
+/*
+ * END: Prevent cyclic inclusion
+ */
+#endif   /* Cyclic inclusion */
